/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Wed Aug  1 00:13:17 BST 2001
    copyright            : (C) 2001 by Richard Moore
    email                : rich@kde.org
 ***************************************************************************/

#include <qtextstream.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>

#include <kmessagebox.h>
#include <kcolordialog.h>
#include <kpassdlg.h>
#include <klineeditdlg.h>
#include <kfiledialog.h>

#include "kstddialog.h"

static const char *description =
	I18N_NOOP("A utility for displaying simple dialogs from the command line.");
	
static KCmdLineOptions options[] =
{
  { "!+text", 
    I18N_NOOP( "The text to be displayed in the dialog." ), 0 
  },
  { "type <dialog type>",
    I18N_NOOP( "The dialog type which must be one of:\n"
      "  info, error, sorry, yesno, about,\n"
      "  warnyesno, warncontcancel, warnyesnocancel,\n"
      "  color, password, lineedit,\n"
      "  openfile, savefile, openurl, saveurl, opendir\n"
      "If no type is specified then 'info' is assumed." ), 0
  },
  { "text <filename>",
    I18N_NOOP( "A filename from which the text should be read." ), 0 
  },
  { 0, 0, 0 }
};

int main(int argc, char *argv[])
{
  KAboutData aboutData( "kstddialog", I18N_NOOP("KMessage"),
			VERSION, description, KAboutData::License_GPL,
			"(c) 2001-2002, Richard Moore", 0, 0, "rich@kde.org");
  aboutData.addAuthor( "Richard Moore", 0, "rich@kde.org" );

  KCmdLineArgs::init( argc, argv, &aboutData );
  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
  KApplication a;

  //
  // Process Arguments
  //
  KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

  // Read the message text
  QString text;
  QString textfile = args->getOption( "text" );
  if ( !textfile.isEmpty() ) {
    // From a file
    QFile f( textfile );
    if ( f.open( IO_ReadOnly ) ) {
      QString line;
      while ( f.readLine( line, 4096 ) != -1 )
	text += line;

      f.close();
    }
  }
  else {
    // From the command line
    for ( int i = 0; i < args->count(); i++ ) {
      if ( i != 0 )
	text += " ";
      text += QString( args->arg(i) );
    }
  }

  // Read the dialog type
  QString type = args->getOption( "type" );
  if ( type.isNull() || type.isEmpty() )
    type = "info";

  //
  // Show Dialog
  //
  QString strResult;
  int result = 0;

  if ( type == "yesno" ) {
    result = KMessageBox::questionYesNo( 0, text, a.caption() );
  }
  else if ( type == "warnyesno" ) {
    result = KMessageBox::warningYesNo( 0, text, a.caption() );
  }
  else if ( type == "warncontcancel" ) {
    result = KMessageBox::warningContinueCancel( 0, text, a.caption(), QString::null );
  }
  else if ( type == "warnyesnocancel" ) {
    result = KMessageBox::warningYesNoCancel( 0, text, a.caption(), QString::null );
  }
  else if ( type == "error" ) {
    KMessageBox::error( 0, text,a.caption() );
  }
  else if ( type == "sorry" ) {
    KMessageBox::sorry( 0, text, a.caption() );
  }
  else if ( type == "info" ) {
    KMessageBox::information( 0, text, a.caption() );
  }
  else if ( type == "about" ) {
    KMessageBox::about( 0, text, a.caption() );
  }
  else if ( type == "color" ) {
    QColor c( text );
    result = KColorDialog::getColor( c );
    strResult = strResult.sprintf( "#%02x%02x%02x",
				   c.red(), c.green(), c.blue() );
  }
  else if ( type == "password" ) {
    QCString pass;
    result = KPasswordDialog::getPassword( pass, text );
    strResult = pass;
  }
  else if ( type == "lineedit" ) {
    bool ok;
    strResult = KLineEditDlg::getText( text, QString::null, &ok, 0 );
    result = ok ? 0 : 1;
  }
  else if ( type == "openfile" ) {
    QString filename = KFileDialog::getOpenFileName( text, QString::null, 0, a.caption() );
    if ( filename.isNull() || filename.isEmpty() )
      result = 1;
  }
  else if ( type == "openurl" ) {
    KURL url = KFileDialog::getOpenURL( text, QString::null, 0, a.caption() );
    if ( url.isEmpty() )
      result = 1;
    else
      strResult = url.url();
  }
  else if ( type == "opendir" ) {
    strResult = KFileDialog::getExistingDirectory( text, 0, a.caption() );
    if ( strResult.isNull() || strResult.isEmpty() )
      result = 1;
  }
  else if ( type == "savefile" ) {
    strResult = KFileDialog::getSaveFileName( text, QString::null, 0, a.caption() );
    if ( strResult.isNull() || strResult.isEmpty() )
      result = 1;
  }
  else if ( type == "saveurl" ) {
    KURL url = KFileDialog::getSaveURL( text, QString::null, 0, a.caption() );
    if ( url.isEmpty() )
      result = 1;
    else
      strResult = url.url();
  }

  if ( !( strResult.isNull() || strResult.isEmpty()) ) {
    QTextStream cout( stdout, IO_WriteOnly );
    cout << strResult;
  }

  a.exit( result );
}
